'use client';

import { useState, useEffect } from 'react';
import Image from 'next/image';
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuLabel,
  DropdownMenuItem,
  DropdownMenuSeparator,
  DropdownMenuTrigger,
} from '@/components/ui/dropdown-menu';
import { createClient } from '@/utils/supabase/client';
import type { Session } from '@supabase/supabase-js';
import { Button } from '@/components/ui/button';
import { redirect } from 'next/navigation';

const AvatarDropdown = () => {
  const supabase = createClient();
  const [session, setSession] = useState<Session | null>(null);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    // Function to fetch the session
    async function fetchSession() {
      try {
        const {
          data: { session },
        } = await supabase.auth.getSession();
        setSession(session);
      } catch (error) {
        console.error('Error fetching session:', error);
      } finally {
        setLoading(false);
      }
    }

    // Call the function
    fetchSession().catch((error) => {
      console.error('Error fetching session:', error);
    });

    // Set up auth state change listener
    const {
      data: { subscription },
    } = supabase.auth.onAuthStateChange((_event, session) => {
      setSession(session);
    });

    // Clean up the subscription when component unmounts
    return () => {
      subscription.unsubscribe();
    };
  }, [supabase]);

  // Handle sign out
  const handleSignOut = async () => {
    await supabase.auth.signOut();
    redirect('/');
  };

  // Show nothing while loading
  if (loading) {
    return <div className='animate-pulse h-8 w-8 rounded-full bg-gray-300' />;
  }

  // If no session, return empty div
  if (!session) {
    return <div />;
  }

  // Get user details
  const pfp =
    (session.user?.user_metadata?.avatar_url as string) ??
    (session.user?.user_metadata?.picture as string) ??
    '/images/default_user_pfp.png';

  const name: string =
    (session.user?.user_metadata?.full_name as string) ??
    (session.user?.user_metadata?.name as string) ??
    (session.user?.email as string) ??
    ('Profile' as string);

  // If no session, return empty div
  if (!session) return <div />;
  return (
    <div className='m-auto mt-1'>
      <DropdownMenu>
        <DropdownMenuTrigger>
          <Image
            src={pfp}
            alt='User profile'
            width={35}
            height={35}
            className='rounded-full border-2 border-white m-auto mr-1 md:mr-2
            max-w-[25px] md:max-w-[35px]'
          />
        </DropdownMenuTrigger>
        <DropdownMenuContent>
          <DropdownMenuLabel>{name}</DropdownMenuLabel>
          <DropdownMenuSeparator />
          <DropdownMenuItem asChild>
            <Button onClick={handleSignOut} className='w-full text-left'>
              Sign Out
            </Button>
          </DropdownMenuItem>
        </DropdownMenuContent>
      </DropdownMenu>
    </div>
  );
};
export default AvatarDropdown;
